@@ -9,8 +9,13 @@ function(x,writeToFile, ...)
 
   dataCombined <- x # match the variable names (this must be used to avoid warnings in package compilation)
 
-  # EnsurePackage("igraph")
-
+  # if `dataCombined` is a list of dataframes, then need to convert these into one dataframe
+  suppressWarnings(
+    if (class(dataCombined)=="list") {
+    dataCombined <- do.call("rbind", dataCombined)
+    }
+  )
+  
   cat("\nCreating Instagram bimodal network...\n")
 
   actors_users <- data.table(id=dataCombined$from_userID,
@@ -42,7 +47,9 @@ function(x,writeToFile, ...)
      full_name=NA,
      profile_picture=NA,
      post_created_time_UNIX_epoch = NA,
-     post_created_time = as.POSIXct(dataCombined$post_created_time, origin="1970-01-01"),
+     # post_created_time = as.POSIXct(dataCombined$post_created_time, origin="1970-01-01"),
+     # post_created_time = NA,
+     post_created_time = dataCombined$post_created_time,
      post_type = dataCombined$post_type,
      post_longitude = dataCombined$post_longitude,
      post_latitude = dataCombined$post_latitude,
@@ -82,6 +89,8 @@ function(x,writeToFile, ...)
     cat(paste0(currTime,"_Instagram_Bimodal_Network.graphml"))
   }
 
+  V(g)$post_created_time <- as.POSIXct(V(g)$post_created_time, origin="1970-01-01")
+
   cat("\nDone!\n") ### DEBUG
   flush.console()
 
